# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/dex_pool_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'evm/dex_pool_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2
from evm import dex_block_message_pb2 as evm_dot_dex__block__message__pb2
from evm import token_block_message_pb2 as evm_dot_token__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n evm/dex_pool_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\x1a\x1b\x65vm/dex_block_message.proto\x1a\x1d\x65vm/token_block_message.proto\"\xdf\x01\n\x13\x44\x65xPoolBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12:\n\nPoolEvents\x18\x05 \x03(\x0b\x32&.evm_messages.PoolLiquidityChangeEvent\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x42\x0b\n\t_L1Header\"\xf2\x02\n\x18PoolLiquidityChangeEvent\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12\x35\n\x14TransactionSignature\x18\x02 \x01(\x0b\x32\x17.evm_messages.Signature\x12\x11\n\tCallIndex\x18\x03 \x01(\x04\x12\x10\n\x08LogIndex\x18\x04 \x01(\x04\x12\x0e\n\x06HasLog\x18\x05 \x01(\x08\x12\"\n\x03\x44\x65x\x18\x06 \x01(\x0b\x32\x15.evm_messages.DexInfo\x12.\n\tLiquidity\x18\x08 \x01(\x0b\x32\x1b.evm_messages.PoolLiquidity\x12\x34\n\x0ePoolPriceTable\x18\t \x01(\x0b\x32\x1c.evm_messages.PoolPriceTable\x12$\n\x04Pool\x18\x0b \x01(\x0b\x32\x16.evm_messages.PoolInfo\"\xb0\x01\n\x08PoolInfo\x12\x15\n\rSmartContract\x18\x01 \x01(\x0c\x12*\n\tCurrencyA\x18\x02 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12*\n\tCurrencyB\x18\x03 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12%\n\x04Pair\x18\x04 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12\x0e\n\x06PoolId\x18\x05 \x01(\x0c\"A\n\rPoolLiquidity\x12\x17\n\x0f\x41mountCurrencyA\x18\x01 \x01(\x0c\x12\x17\n\x0f\x41mountCurrencyB\x18\x02 \x01(\x0c\"b\n\tPoolPrice\x12\x1b\n\x13SlippageBasisPoints\x18\x01 \x01(\r\x12\x13\n\x0bMaxAmountIn\x18\x02 \x01(\x0c\x12\x14\n\x0cMinAmountOut\x18\x03 \x01(\x0c\x12\r\n\x05Price\x18\x04 \x01(\x02\"\x90\x01\n\x0ePoolPriceTable\x12+\n\nAtoBPrices\x18\x01 \x03(\x0b\x32\x17.evm_messages.PoolPrice\x12+\n\nBtoAPrices\x18\x02 \x03(\x0b\x32\x17.evm_messages.PoolPrice\x12\x11\n\tAtoBPrice\x18\x03 \x01(\x02\x12\x11\n\tBtoAPrice\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.dex_pool_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEXPOOLBLOCKMESSAGE']._serialized_start=136
  _globals['_DEXPOOLBLOCKMESSAGE']._serialized_end=359
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_start=362
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_end=732
  _globals['_POOLINFO']._serialized_start=735
  _globals['_POOLINFO']._serialized_end=911
  _globals['_POOLLIQUIDITY']._serialized_start=913
  _globals['_POOLLIQUIDITY']._serialized_end=978
  _globals['_POOLPRICE']._serialized_start=980
  _globals['_POOLPRICE']._serialized_end=1078
  _globals['_POOLPRICETABLE']._serialized_start=1081
  _globals['_POOLPRICETABLE']._serialized_end=1225
# @@protoc_insertion_point(module_scope)
